@@ -1,11 +1,11 @@
 ## File Name: mice.impute.pmm3.R
-## File Version: 4.56
+## File Version: 4.57
 
 
 mice.impute.pmm3 <- function (y, ry, x, donors=3, noise=10^5, ridge=10^(-5), ...)
 {
     x <- cbind(1, as.matrix(x))
-    res <- miceadds_norm_draw(y=y, ry=ry, x=x, ridge=ridge, ...)
+    res <- mice_imputation_norm_draw(y=y, ry=ry, x=x, ridge=ridge, ...)
     yhatobs <- res$yhatobs
     yhatmis <- res$yhatmis
     yobs <- res$yobs
